@@ -3,9 +3,13 @@
 
 import base64
 import hashlib
+import typing
+
+if typing.TYPE_CHECKING:
+    from _typeshed import ReadableBuffer
 
 
-def encode(data: bytes) -> str:
+def encode(data: "ReadableBuffer") -> str:
     return base64.b64encode(data).decode("utf-8")
 
 
