@@ -1252,7 +1252,9 @@ class ModelBase(DyffSchemaBaseModel):
         description="How the model data is represented"
     )
 
-    storage: ModelStorage = pydantic.Field(description="How the model data is stored")
+    storage: Optional[ModelStorage] = pydantic.Field(
+        default=None, description="How the model data is stored"
+    )
 
 
 class ModelSpec(ModelBase):
@@ -1442,10 +1444,15 @@ class Container(DyffSchemaBaseModel):
 
 
 class InferenceServiceRunner(Container):
-    """Configuration of a managed runner to use to run an inference service.
+    """Configuration of the runtime environment to use to run an inference service.
 
-    Using a managed runner simplifies the configuration of inference services backed by
-    models in common formats, such as HuggingFace models.
+    You can run the service in an arbitrary Docker container by using
+    ``.kind == "container" and setting ``.imageRef`` to a container image that
+    has been uploaded to Dyff using the ``/artifacts/create`` API.
+
+    Other runner kinds are "managed" runners that are maintained as part of the
+    Dyff project. Using a managed runner simplifies the configuration of
+    inference services backed by models in common formats, such as HuggingFace models.
     """
 
     kind: InferenceServiceRunnerKind
@@ -1492,8 +1499,7 @@ class InferenceServiceBase(DyffSchemaBaseModel):
     # FIXME: (DYFF-261) .runner should be required
     runner: Optional[InferenceServiceRunner] = pydantic.Field(
         default=None,
-        description="Configuration of the managed runner used to run the service."
-        " Only one of .container or .runner may be specified.",
+        description="Configuration of the managed runner used to run the service.",
     )
 
     interface: InferenceInterface = pydantic.Field(
@@ -2276,10 +2282,6 @@ class Score(ScoreData):
 class OCIArtifact(DyffEntity):
     kind: Literal["OCIArtifact"] = Entities.Artifact.value
 
-    manifest: oci.ImageManifest = pydantic.Field(
-        description="The OCI image manifest of the artifact"
-    )
-
     def dependencies(self) -> list[str]:
         return []
 
