@@ -133,7 +133,7 @@ class AnalysisCreateRequest(DyffEntityCreateRequest, AnalysisBase):
 
 
 class ArtifactCreateRequest(DyffEntityCreateRequest):
-    manifest: oci.ImageManifest
+    pass
 
 
 class ConcernCreateRequest(DyffEntityCreateRequest, ConcernBase):
@@ -171,11 +171,13 @@ class InferenceServiceCreateRequest(DyffEntityCreateRequest, InferenceServiceBas
     )
 
     @pydantic.model_validator(mode="after")
-    def check_image_exactly_one(cls, values):
-        image = values.image is not None
-        imageRef = values.imageRef is not None
+    def check_runner_and_image_specified(cls, values):
+        if values.runner is None:
+            raise ValueError("must specify .runner in new inference services")
+        image = values.runner.image is not None
+        imageRef = values.runner.imageRef is not None
         if sum([image, imageRef]) != 1:
-            raise ValueError("must specify exactly one of {image, imageRef}")
+            raise ValueError("must specify exactly one of .runner.{image, imageRef}")
         return values
 
 
